netapp_ontap.models.snapmirror_endpoint API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.snapmirror_endpoint`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class SnapmirrorEndpointSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the SnapmirrorEndpoint object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `cluster GET POST PATCH`

    The cluster field of the snapmirror_endpoint.

  `consistency_group_volumes GET POST PATCH`

    Mandatory property for a Consistency Group endpoint. Specifies the list of FlexVol volumes for a Consistency Group.

  `ipspace POST`

    Optional property to specify the IPSpace of the SVM.

    Example: Default

  `path GET POST PATCH`

    ONTAP FlexVol/FlexGroup - svm1:volume1 ONTAP SVM - svm1: ONTAP Consistency Group - svm1:/cg/cg_name

    Example: svm1:volume1

  `svm GET POST PATCH`

    The svm field of the snapmirror_endpoint.